(function() {
  let chatOpen = false;
  let messages = [];
  const STORAGE_KEY = 'supportherowp_chat_messages';
  let typingTimeout;

  function loadChatHistory() {
    try {
      const saved = localStorage.getItem(STORAGE_KEY);
      if (saved) messages = JSON.parse(saved);
    } catch(e){}
  }
  function saveChatHistory() {
    localStorage.setItem(STORAGE_KEY, JSON.stringify(messages));
  }
  function initFloatingElements() {
    const icon = document.createElement('div');
    icon.id = 'supportherowp-floating-icon';
    icon.innerHTML = '<img src="' + supportherowpChat.pluginUrl + 'assets/images/logo.png" alt="Chat"/>';
    document.body.appendChild(icon);

    const chatBox = document.createElement('div');
    chatBox.id = 'supportherowp-floating-chat';
    chatBox.innerHTML = `
      <div id="supportherowp-floating-chat-header">
        <span>SupportHeroWP</span>
        <span id="supportherowp-floating-chat-close">✕</span>
      </div>
      <div id="supportherowp-floating-chat-messages"></div>
      <div id="supportherowp-floating-chat-input">
        <input type="text" id="supportherowp-floating-chat-text" placeholder="Type your message..." />
        <button id="supportherowp-floating-chat-send">➤</button>
      </div>
    `;
    document.body.appendChild(chatBox);

    icon.addEventListener('click', () => {
      chatOpen = !chatOpen;
      if (chatOpen) {
        chatBox.classList.add('show');
        renderMessages();
        scrollToBottom();
      } else {
        chatBox.classList.remove('show');
      }
    });
    chatBox.querySelector('#supportherowp-floating-chat-close').addEventListener('click', () => {
      chatOpen = false;
      chatBox.classList.remove('show');
    });
    chatBox.querySelector('#supportherowp-floating-chat-send').addEventListener('click', sendMessage);
    chatBox.querySelector('#supportherowp-floating-chat-text').addEventListener('keypress', e => {
      if(e.key === 'Enter') {
        e.preventDefault();
        sendMessage();
      }
    });
    renderMessages();
  }
  function renderMessages() {
    const container = document.getElementById('supportherowp-floating-chat-messages');
    if (!container) return;
    container.innerHTML = '';
    messages.forEach(msg => {
      const row = document.createElement('div');
      row.className = 'supportherowp-floating-chat-msg ' + msg.sender;
      const bubble = document.createElement('div');
      bubble.className = 'supportherowp-floating-chat-bubble';
      if (msg.sender === 'ai') {
        // Use a markdown parser like "marked" to parse AI responses
        bubble.innerHTML = window.marked ? marked.parse(msg.message) : msg.message;
      } else {
        bubble.textContent = msg.message;
      }
      row.appendChild(bubble);
      container.appendChild(row);
    });
    scrollToBottom();
  }
  function scrollToBottom() {
    const container = document.getElementById('supportherowp-floating-chat-messages');
    if (container) {
      container.scrollTop = container.scrollHeight;
    }
  }
  function sendMessage() {
    const input = document.getElementById('supportherowp-floating-chat-text');
    if (!input) return;
    const txt = input.value.trim();
    if (!txt) return;
    messages.push({ sender:'user', message:txt });
    input.value = '';
    renderMessages();
    saveChatHistory();

    // Display typing indicator
    const container = document.getElementById('supportherowp-floating-chat-messages');
    const typingIndicator = document.createElement('div');
    typingIndicator.className = 'supportherowp-floating-chat-msg ai typing';
    typingIndicator.innerHTML = `
      <div class="supportherowp-floating-chat-bubble">
        <div class="typing-indicator">
          <span></span><span></span><span></span>
        </div>
      </div>
    `;
    container.appendChild(typingIndicator);
    scrollToBottom();

    const formData = new URLSearchParams();
    formData.append('action','supportherowp_chat');
    formData.append('nonce',supportherowpChat.chatNonce);
    formData.append('message',txt);

    fetch(supportherowpChat.ajaxUrl, {
      method:'POST',
      headers:{ 'Content-Type':'application/x-www-form-urlencoded' },
      body: formData
    })
    .then(r=>r.json())
    .then(data=>{
      // Remove typing indicator
      if (typingIndicator.parentNode) {
        typingIndicator.parentNode.removeChild(typingIndicator);
      }
      if(data.success) {
        messages.push({ sender:'ai', message:data.data.reply });
      } else {
        messages.push({ sender:'ai', message:data.data || 'Unknown error.' });
      }
      renderMessages();
      saveChatHistory();
    })
    .catch(e=>{
      // Remove typing indicator
      if (typingIndicator.parentNode) {
        typingIndicator.parentNode.removeChild(typingIndicator);
      }
      messages.push({ sender:'ai', message:'Server error or no response from server.' });
      renderMessages();
      saveChatHistory();
    });
  }
  document.addEventListener('DOMContentLoaded', () => {
    loadChatHistory();
    initFloatingElements();
  });
})();
