<?php
class SupportHeroWP_Dashboard {
    protected $scanner;

    public function __construct() {
        $this->scanner = new Diagnostic_Scanner();
    }

    public function init() {
        // Register AJAX handlers
        add_action('wp_ajax_supportherowp_scan', [$this->scanner, 'handle_scan']);
        add_action('wp_ajax_supportherowp_recommend', [$this, 'handle_recommendations']);
        add_action('wp_ajax_supportherowp_escalate', [$this, 'handle_escalation']);
        // New AJAX handler to store scan data
        add_action('wp_ajax_supportherowp_store_scan_data', [$this, 'handle_store_scan_data']);
    }


    public function handle_store_scan_data() {
        check_ajax_referer('supportherowp_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }

        $scan_data_json = isset($_POST['scan_data']) ? wp_unslash($_POST['scan_data']) : '';

        if (empty($scan_data_json)) {
            wp_send_json_error('No scan data provided', 400);
        }

        $scan_data = json_decode($scan_data_json, true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            wp_send_json_error('Invalid scan data format', 400);
        }

        $user_id = get_current_user_id();
        update_user_meta($user_id, 'supportherowp_scan_data', $scan_data);

        wp_send_json_success('Scan data stored successfully.');
    }

    public function handle_recommendations() {
        check_ajax_referer('supportherowp_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }

        $scan_data = isset($_POST['scan_data']) ? sanitize_text_field($_POST['scan_data']) : '';

        if (empty($scan_data)) {
            wp_send_json_error('No scan data provided', 400);
        }

        $recommender = new Maintenance_Recommender();
        $recommendations = $recommender->get_recommendations($scan_data);
        wp_send_json_success($recommendations);
    }

    public function handle_escalation() {
        check_ajax_referer('supportherowp_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized', 403);
        }

        $scan_data = isset($_POST['scan_data']) ? sanitize_text_field($_POST['scan_data']) : '';
        $recommendations = isset($_POST['recommendations']) ? sanitize_text_field($_POST['recommendations']) : '';

        if (empty($scan_data) || empty($recommendations)) {
            wp_send_json_error('Incomplete data provided', 400);
        }

        $escalation = new Expert_Escalation();
        $result = $escalation->escalate_issue($scan_data, $recommendations);

        if ($result) {
            wp_send_json_success('Issue escalated to experts successfully.');
        } else {
            wp_send_json_error('Failed to escalate the issue.');
        }
    }
}
