<?php
use GuzzleHttp\Client;

class AI_Service {
    protected $client;
    protected $api_key;

    public function __construct() {
        $this->api_key = get_option('supportherowp_openai_key'); // Fetch API key from settings
        if (empty($this->api_key)) {
            // Log a notice and return without initializing the client
            error_log('SupportHeroWP: OpenAI API key is not set.');
            $this->client = null;
            return;
        }

        $this->client = new Client([
            'base_uri' => 'https://api.openai.com/v1/',
            'headers' => [
                'Authorization' => 'Bearer ' . $this->api_key,
                'Content-Type' => 'application/json',
            ],
        ]);
    }

    public function is_ready() {
        return $this->client !== null;
    }

    public function analyze($data) {
        if (!$this->is_ready()) {
            return 'AI Service is not initialized. Set the API key in plugin settings.';
        }

        try {
            $response = $this->client->post('chat/completions', [
                'json' => [
                    'model' => 'gpt-4o-mini',
                    'messages' => [
                        ['role' => 'system', 'content' => 'You are an AI WordPress diagnostics assistant.'],
                        ['role' => 'user', 'content' => $data],
                    ],
                    'max_tokens' => 500,
                ],
            ]);

            $body = json_decode($response->getBody(), true);
            return $body['choices'][0]['message']['content'] ?? 'No suggestions available.';
        } catch (Exception $e) {
            return 'Error: ' . $e->getMessage();
        }
    }
}

