// src/components/Layout.jsx

import React, { useState } from 'react';
import Sidebar from './Sidebar';
import Header from './Header';
import MainContent from './MainContent';
import menuItems from '../menuItems'; // Import menuItems for defaultPage validation

const Layout = ({ currentUser, defaultPage }) => {
  // Validate defaultPage against menuItems to ensure it exists
  const isValidPage = menuItems.some(item => item.page === defaultPage);
  const initialPage = isValidPage ? defaultPage : 'dashboard';
  
  const [currentPage, setCurrentPage] = useState(initialPage); // Set initial page based on defaultPage

  return (
    <div className="flex bg-white">
      <Sidebar currentPage={currentPage} onChangePage={setCurrentPage} />
      <div className="flex-1 flex flex-col">
        <Header currentUser={currentUser} onChangePage={setCurrentPage} />
        <MainContent currentPage={currentPage} />
      </div>
    </div>
  );
};

export default Layout;
