// src/components/Sidebar.jsx

import React from 'react';
import menuItems from '../menuItems';

const Sidebar = ({ currentPage, onChangePage }) => {
  // Separate top and bottom items based on their presence in menuItems
  const topNavItems = menuItems.filter(item => !['unlock', 'help'].includes(item.page));
  const bottomNavItems = menuItems.filter(item => ['unlock', 'help'].includes(item.page));

  return (
    <div id="supportherowp-dashboard" className="bg-white text-gray-700 w-52 min-h-screen flex flex-col">
      {/* Logo Section */}
      <div className="p-6 flex items-center justify-center border-gray-300">
        <img
          src={supportherowp.pluginUrl + 'assets/images/logo.png'}
          alt="SupportHeroWP"
          className="h-20 w-auto"
        />
      </div>

      {/* Top Navigation Items */}
      <nav className="flex-1 p-4">
        <ul className="space-y-2">
          {topNavItems.map((item) => {
            const isActive = currentPage === item.page;
            return (
              <li key={item.page}>
                <button
                  onClick={() => onChangePage(item.page)}
                  className={`group flex items-center space-x-3 px-3 py-4 rounded-lg w-full text-left ${
                    isActive
                      ? 'bg-orange-500 text-white font-semibold'
                      : 'hover:bg-orange-500 hover:text-white text-gray-600'
                  }`}
                >
                  <span
                    className={`text-xl ${
                      isActive
                        ? 'text-white'
                        : 'text-gray-400 group-hover:text-white'
                    }`}
                  >
                    {item.icon}
                  </span>
                  <span>{item.label}</span>
                </button>
              </li>
            );
          })}
        </ul>
      </nav>

      {/* Bottom Navigation Items */}
      <nav className="p-4 border-gray-300">
        <ul className="space-y-2">
          {bottomNavItems.map((item) => (
            <li key={item.page}>
              <button
                onClick={() => onChangePage(item.page)}
                className="group flex items-center space-x-3 px-3 py-4 rounded-lg w-full text-left hover:bg-orange-500 hover:text-white text-gray-600"
              >
                <span className="text-lg text-gray-400 group-hover:text-white">
                  {item.icon}
                </span>
                <span>{item.label}</span>
              </button>
            </li>
          ))}
        </ul>
      </nav>
    </div>
  );
};

export default Sidebar;
