// src/pages/Help.jsx

import React, { useState } from 'react';
import {
  FaQuestionCircle,
  FaRobot,
  FaSearch,
  FaPlug,
  FaEnvelope,
} from 'react-icons/fa';

const helpSections = [
  {
    id: 1,
    title: 'Getting Started',
    icon: <FaPlug className="text-blue-500 w-6 h-6" />,
    content: (
      <p>
        Install SupportHeroWP via the WordPress plugin repository or manually upload it. 
        Activate it and go to <strong>Dashboard</strong> to start diagnosing your site.
      </p>
    ),
  },
  {
    id: 2,
    title: 'Using Diagnostics',
    icon: <FaSearch className="text-orange-500 w-6 h-6" />,
    content: (
      <p>
        To analyze your site, click <strong>Scan Now</strong> on the Dashboard. 
        Review performance, security, and plugin/theme diagnostics.
      </p>
    ),
  },
  {
    id: 3,
    title: 'AI Chat Assistance',
    icon: <FaRobot className="text-green-500 w-6 h-6" />,
    content: (
      <p>
        The AI chat helps troubleshoot issues. Use it from the floating chat icon or the Dashboard 
        to get recommendations based on your site's analysis.
      </p>
    ),
  },
];

const faqSections = [
  {
    question: 'Why is my scan not working?',
    answer: (
      <p>
        Ensure your site is online and the plugin has required permissions. 
        Check if your WordPress and SupportHeroWP are up-to-date.
      </p>
    ),
  },
  {
    question: 'How do I reset plugin settings?',
    answer: (
      <p>
        Navigate to <strong>Settings</strong>, then click <strong>Reset Settings</strong>. 
        This will restore defaults without affecting scan data.
      </p>
    ),
  },
  {
    question: 'What does the AI chat do?',
    answer: (
      <p>
        The AI chat offers recommendations based on your scans. 
        It can help optimize performance, resolve security issues, and more.
      </p>
    ),
  },
];

const Help = () => {
  const [activeFAQ, setActiveFAQ] = useState(null);

  const toggleFAQ = (index) => {
    setActiveFAQ(activeFAQ === index ? null : index);
  };

  return (
    <div className="p-6 bg-[#f9f9f9] h-full font-poppins">
      <h2 className="text-2xl font-semibold text-gray-800 mb-6">Help & Documentation</h2>

      {/* Help Sections */}
      <div className="grid grid-cols-1 md:grid-cols-3 gap-6 mb-6">
        {helpSections.map((section) => (
          <div key={section.id} className="bg-white rounded-lg  p-6 flex flex-col items-start">
            <div className="p-2 bg-gray-100 rounded-full mb-4">{section.icon}</div>
            <h3 className="text-lg font-semibold text-gray-800 mb-2">{section.title}</h3>
            <div className="text-gray-600 text-sm">{section.content}</div>
          </div>
        ))}
      </div>

      {/* FAQ Section */}
      <div className="bg-white rounded-lg  p-6 mb-6">
        <h3 className="text-xl font-semibold text-gray-800 mb-4">Frequently Asked Questions</h3>
        <div>
          {faqSections.map((faq, index) => (
            <div
              key={index}
              className="border-b border-gray-200 py-4"
            >
              <button
                className="w-full text-left flex justify-between items-center focus:outline-none"
                onClick={() => toggleFAQ(index)}
              >
                <span className="text-gray-800 font-semibold">{faq.question}</span>
                <span className="text-gray-600">{activeFAQ === index ? '-' : '+'}</span>
              </button>
              {activeFAQ === index && (
                <div className="mt-2 text-gray-600 text-sm">{faq.answer}</div>
              )}
            </div>
          ))}
        </div>
      </div>

      {/* Contact Support Section */}
      <div className="bg-white rounded-lg  px-6 py-14  text-center">
        <h3 className="text-xl font-semibold text-gray-800 mb-4">Need More Help?</h3>
        <p className="text-gray-600 text-sm mb-4">
          Can't find what you're looking for? Contact our support team for further assistance.
        </p>
        <a
          href="mailto:support@supportherowp.com"
          className="bg-orange-500 text-white px-4 py-2 rounded-lg hover:bg-orange-600 hover:text-white transition"
        >
          Contact Support
        </a>
      </div>
    </div>
  );
};

export default Help;
