// src/pages/Integration.jsx

import React from 'react';
import { FaShieldAlt, FaRocket, FaChartLine, FaCloud, FaCodeBranch } from 'react-icons/fa';

const integrations = [
  {
    id: 1,
    title: 'WordPress Security Plugins',
    description: 'Integrate with Wordfence or Sucuri to enhance your site security.',
    icon: <FaShieldAlt className="text-green-500 w-6 h-6" />,
    comingSoon: true,
  },
  {
    id: 2,
    title: 'Performance Analysis',
    description: 'Connect to WP Rocket or Google PageSpeed for performance diagnostics.',
    icon: <FaRocket className="text-orange-500 w-6 h-6" />,
    comingSoon: true,
  },
  {
    id: 3,
    title: 'SEO Tools',
    description: 'Link with Yoast or RankMath for comprehensive SEO recommendations.',
    icon: <FaChartLine className="text-blue-500 w-6 h-6" />,
    comingSoon: true,
  },
  {
    id: 4,
    title: 'Cloud Backups',
    description: 'Integrate with Amazon S3 or Google Cloud for backups.',
    icon: <FaCloud className="text-yellow-500 w-6 h-6" />,
    comingSoon: true,
  },
  {
    id: 5,
    title: 'Developer Tools',
    description: 'Sync with GitHub or Bitbucket for version control.',
    icon: <FaCodeBranch className="text-purple-500 w-6 h-6" />,
    comingSoon: true,
  },
];

const Integration = () => {
  return (
    <div className="p-6 bg-[#f9f9f9] h-full font-poppins">
      <h2 className="text-2xl font-semibold text-gray-800 mb-6">Potential Integrations</h2>

      {/* Bento Grid */}
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
        {integrations.map((integration) => (
          <div key={integration.id} className="bg-white rounded-lg p-6 flex flex-col items-start">
            {/* Icon */}
            <div className="p-2 bg-gray-100 rounded-full mb-4">{integration.icon}</div>

            {/* Title */}
            <h3 className="text-lg font-semibold text-gray-800 mb-2">{integration.title}</h3>

            {/* Description */}
            <p className="text-gray-600 text-sm mb-4">{integration.description}</p>

            {/* Coming Soon */}
            {integration.comingSoon && (
              <button
                className="mt-auto bg-gray-300 text-gray-700 px-4 py-2 rounded-lg cursor-not-allowed"
                disabled
              >
                Coming Soon
              </button>
            )}
          </div>
        ))}
      </div>
    </div>
  );
};

export default Integration;
