// src/pages/Maintain.jsx

import React from 'react';
import { FaDatabase, FaShieldAlt, FaCogs, FaTrashAlt, FaImages, FaClock } from 'react-icons/fa';

const tasks = [
  {
    id: 1,
    title: 'Optimize Database',
    description: 'Clean up unused tables and optimize database queries.',
    icon: <FaDatabase className="text-orange-500 w-6 h-6" />,
  },
  {
    id: 2,
    title: 'Check File Permissions',
    description: 'Ensure critical files have secure permissions.',
    icon: <FaShieldAlt className="text-green-500 w-6 h-6" />,
  },
  {
    id: 3,
    title: 'Remove Inactive Plugins',
    description: 'Identify and remove unused or inactive plugins.',
    icon: <FaTrashAlt className="text-red-500 w-6 h-6" />,
  },
  {
    id: 4,
    title: 'Optimize Images',
    description: 'Compress and optimize large images for better performance.',
    icon: <FaImages className="text-blue-500 w-6 h-6" />,
  },
  {
    id: 5,
    title: 'Enable Lazy Loading',
    description: 'Improve page speed by lazy loading images.',
    icon: <FaClock className="text-yellow-500 w-6 h-6" />,
  },
];

const Maintain = () => {
  return (
    <div className="p-6 bg-[#f9f9f9] h-full font-poppins">
      <h2 className="text-2xl font-semibold text-gray-800 mb-6">Maintenance Tasks</h2>

      {/* Bento Grid */}
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
        {tasks.map((task) => (
          <div key={task.id} className="bg-white rounded-lg p-6 flex flex-col items-start">
            {/* Icon */}
            <div className="p-2 bg-gray-100 rounded-full mb-4">{task.icon}</div>

            {/* Title */}
            <h3 className="text-lg font-semibold text-gray-800 mb-2">{task.title}</h3>

            {/* Description */}
            <p className="text-gray-600 text-sm mb-4">{task.description}</p>

            {/* Status */}
            {/* <div className="text-sm mb-4">
              <span className="px-2 py-1 rounded-full bg-yellow-100 text-yellow-600">
                Coming Soon
              </span>
            </div> */}

            {/* Action Button */}
            <button
                className="mt-auto bg-gray-300 text-gray-700 px-4 py-2 rounded-lg cursor-not-allowed"
                disabled
              >
                Coming Soon
            </button>
          </div>
        ))}
      </div>
    </div>
  );
};

export default Maintain;
