<?php
/**
 * Plugin Name: SupportHeroWP
 * Description: The Most Powerful AI Tool for WordPress Diagnostics and Maintenance.
 * Version: 1.0.0
 * Author: SupportHeroWP
 * Text Domain: supportherowp
 */

if (!defined('ABSPATH')) {
    exit;
}

define('SUPPORTHEROWP_VERSION', '1.0.0');
define('SUPPORTHEROWP_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('SUPPORTHEROWP_PLUGIN_URL', plugin_dir_url(__FILE__));

if (file_exists(SUPPORTHEROWP_PLUGIN_DIR . 'vendor/autoload.php')) {
    require_once SUPPORTHEROWP_PLUGIN_DIR . 'vendor/autoload.php';
}

require_once SUPPORTHEROWP_PLUGIN_DIR . 'includes/class-supportherowp.php';
require_once SUPPORTHEROWP_PLUGIN_DIR . 'includes/class-ai-service.php';
require_once SUPPORTHEROWP_PLUGIN_DIR . 'includes/class-diagnostic-scanner.php';
require_once SUPPORTHEROWP_PLUGIN_DIR . 'includes/class-expert-escalation.php';
require_once SUPPORTHEROWP_PLUGIN_DIR . 'includes/class-maintenance-recommender.php';
require_once SUPPORTHEROWP_PLUGIN_DIR . 'includes/admin/class-admin.php';
require_once SUPPORTHEROWP_PLUGIN_DIR . 'includes/admin/class-dashboard.php';

function supportherowp_init() {
    $admin = new SupportHeroWP_Admin();
    $admin->init();
    $scanner = new Diagnostic_Scanner();
    add_action('wp_ajax_supportherowp_scan', [$scanner, 'handle_scan']);
    add_action('wp_ajax_supportherowp_chat', [$scanner, 'handle_chat']);
    // NEW lines to register additional endpoints on the same $scanner
    add_action('wp_ajax_supportherowp_get_scan_histories', [$scanner, 'handle_get_scan_histories']);
    add_action('wp_ajax_supportherowp_delete_scan_history', [$scanner, 'handle_delete_scan_history']);
}
add_action('plugins_loaded', 'supportherowp_init');

function supportherowp_activate() {
    Diagnostic_Scanner::activate();

    if (empty(get_option('supportherowp_openai_key'))) {
        add_option('supportherowp_activation_notice', true);
    }
}
register_activation_hook(__FILE__, 'supportherowp_activate');

// Display Admin Notice
add_action('admin_notices', function () {
    if (get_option('supportherowp_activation_notice')) {
        echo '<div class="notice notice-warning is-dismissible">
                <p>Please configure the OpenAI API key in SupportHeroWP settings.</p>
             </div>';
        delete_option('supportherowp_activation_notice');
    }
});


function supportherowp_enqueue_floating_chat() {
    if (is_admin()) {
        $screen = get_current_screen();
        if ($screen) {
            // List all admin screens where you want to hide the floating chat
            $excluded_screens = ['plugins', 'supportherowp']; // Adjust 'plugin_page_supportherowp_dashboard' as per your dashboard screen ID
            if (in_array($screen->base, $excluded_screens)) {
                return; // Do not load chat on these screens
            }
        }
    }

    wp_enqueue_script(
        'supportherowp-marked',
        'https://cdn.jsdelivr.net/npm/marked@4.3.0/marked.min.js',
        [],
        '4.3.0',
        true
    );
    wp_enqueue_script(
        'supportherowp-floating-chat',
        SUPPORTHEROWP_PLUGIN_URL . 'assets/js/floating-chat.js',
        ['supportherowp-marked'],
        SUPPORTHEROWP_VERSION,
        true
    );
    wp_localize_script('supportherowp-floating-chat', 'supportherowpChat', [
        'ajaxUrl'  => admin_url('admin-ajax.php'),
        'chatNonce' => wp_create_nonce('supportherowp_chat_nonce'),
        'pluginUrl' => SUPPORTHEROWP_PLUGIN_URL
    ]);
    wp_enqueue_style(
        'supportherowp-floating-chat-css',
        SUPPORTHEROWP_PLUGIN_URL . 'assets/css/floating-chat.css',
        [],
        SUPPORTHEROWP_VERSION
    );
}
add_action('wp_enqueue_scripts', 'supportherowp_enqueue_floating_chat');
add_action('admin_enqueue_scripts', 'supportherowp_enqueue_floating_chat');
